==> kdenlive_20.12.3.orig.tar.xz: kdenlive-20.12.3/src/assets/view/widgets/doubleparamwidget.hpp <==
/***************************************************************************
 *   Copyright (C) 2016 by Nicolas Carion                                  *
 *   This file is part of Kdenlive. See www.kdenlive.org.                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3 or any later version accepted by the       *
 *   membership of KDE e.V. (or its successor approved  by the membership  *
 *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
 *   version 3 of the license.                                             *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef DOUBLEPARAMWIDGET_H
#define DOUBLEPARAMWIDGET_H

#include "abstractparamwidget.hpp"
#include <QModelIndex>
#include <memory>

/** @brief This represent a double parameter

 */

class AssetParameterModel;
class DoubleWidget;
class QVBoxLayout;

class DoubleParamWidget : public AbstractParamWidget
{
    Q_OBJECT
public:
    DoubleParamWidget() = delete;
    DoubleParamWidget(std::shared_ptr<AssetParameterModel> model, QModelIndex index, QWidget *parent);

public slots:
    /** @brief Toggle the comments on or off
     */
    void slotShowComment(bool show) override;

    /** @brief refresh the properties to reflect changes in the model
     */
    void slotRefresh() override;

protected:
    DoubleWidget *m_doubleWidget;
    QVBoxLayout *m_lay;
};

#endif

==> kdenlive-21.08.1.tar.xz: kdenlive-21.08.1/src/assets/view/widgets/doubleparamwidget.hpp <==
/***************************************************************************
 *   Copyright (C) 2016 by Nicolas Carion                                  *
 *   This file is part of Kdenlive. See www.kdenlive.org.                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3 or any later version accepted by the       *
 *   membership of KDE e.V. (or its successor approved  by the membership  *
 *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
 *   version 3 of the license.                                             *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef DOUBLEPARAMWIDGET_H
#define DOUBLEPARAMWIDGET_H

#include "abstractparamwidget.hpp"
#include <QModelIndex>
#include <memory>

class AssetParameterModel;
class DoubleWidget;
class QVBoxLayout;

/** @class DoubleParamWidget
    @brief This represent a double parameter
 */
class DoubleParamWidget : public AbstractParamWidget
{
    Q_OBJECT
public:
    DoubleParamWidget() = delete;
    DoubleParamWidget(std::shared_ptr<AssetParameterModel> model, QModelIndex index, QWidget *parent);

public slots:
    /** @brief Toggle the comments on or off
     */
    void slotShowComment(bool show) override;

    /** @brief refresh the properties to reflect changes in the model
     */
    void slotRefresh() override;

protected:
    DoubleWidget *m_doubleWidget;
    QVBoxLayout *m_lay;
};

#endif
